summaryrefslogtreecommitdiffstats
path: root/kioslave/thumbnail/thumbnail.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:17:06 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:17:06 -0600
commite4e0479220e9e9616b68b2a11e42cff7a8af7b3d (patch)
tree8e01571cdd132dad34ebec38b12c2dbc37d05bd9 /kioslave/thumbnail/thumbnail.cpp
parentd41050ea3f6904e5156d35f664346b816b9e4d12 (diff)
downloadtdebase-e4e0479220e9e9616b68b2a11e42cff7a8af7b3d.tar.gz
tdebase-e4e0479220e9e9616b68b2a11e42cff7a8af7b3d.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
Diffstat (limited to 'kioslave/thumbnail/thumbnail.cpp')
-rw-r--r--kioslave/thumbnail/thumbnail.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kioslave/thumbnail/thumbnail.cpp b/kioslave/thumbnail/thumbnail.cpp
index 6e81b61d3..b73528610 100644
--- a/kioslave/thumbnail/thumbnail.cpp
+++ b/kioslave/thumbnail/thumbnail.cpp
@@ -53,7 +53,7 @@
#include "thumbnail.h"
#include <kio/thumbcreator.h>
// Use correctly KInstance instead of KApplication (but then no TQPixmap)
#undef USE_KINSTANCE
// Fix thumbnail: protocol
#define THUMBNAIL_HACK (1)
@@ -98,16 +98,16 @@ int kdemain(int argc, char **argv)
#ifdef USE_KINSTANCE
KInstance instance("kio_thumbnail");
#else
// creating KApplication in a slave in not a very good idea,
// as dispatchLoop() doesn't allow it to process its messages,
// so it for example wouldn't reply to ksmserver - on the other
// hand, this slave uses QPixmaps for some reason, and they
// need QApplication
// and HTML previews need even KApplication :(
putenv(strdup("SESSION_MANAGER="));
- KApplication::disableAutoDcopRegistration();
+ TDEApplication::disableAutoDcopRegistration();
- KApplication app(argc, argv, "kio_thumbnail", false, true);
+ TDEApplication app(argc, argv, "kio_thumbnail", false, true);
#endif
if (argc != 4)
@@ -53,7 +53,7 @@
#include "thumbnail.h"
#include <kio/thumbcreator.h>
-// Use correctly KInstance instead of KApplication (but then no TQPixmap)
+// Use correctly KInstance instead of TDEApplication (but then no TQPixmap)
#undef USE_KINSTANCE
// Fix thumbnail: protocol
@@ -98,16 +98,16 @@ int kdemain(int argc, char **argv)
KInstance instance("kio_thumbnail");
#else
- // creating KApplication in a slave in not a very good idea,
+ // creating TDEApplication in a slave in not a very good idea,
// as dispatchLoop() doesn't allow it to process its messages,
// so it for example wouldn't reply to ksmserver - on the other
@@ -98,16 +98,16 @@ int kdemain(int argc, char **argv)
// hand, this slave uses QPixmaps for some reason, and they
// need QApplication
- // and HTML previews need even KApplication :(
+ // and HTML previews need even TDEApplication :(
putenv(strdup("SESSION_MANAGER="));